==> org.opennms.features.topology.api-21.1.0-20190418.041154-57-sources.jar: org/opennms/features/topology/api/topo/Edge.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2012-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.topology.api.topo;

import com.vaadin.data.Item;

public interface Edge extends EdgeRef, Cloneable {

	Edge clone();

	/**
	 * Allow code to override the ID on cloned instances.
	 */
	void setId(String id);

	/**
	 * @deprecated Use namespace/id tuple
	 */
	String getKey();

	Item getItem();

	Connector getSource();

	Connector getTarget();

	@Override
	String getLabel();

	String getTooltipText();

	void setTooltipText(String tooltipText);

	String getStyleName();

	void setStyleName(String styleName);

}

==> org.opennms.features.topology.api-26.0.0-20200128.022242-58-sources.jar: org/opennms/features/topology/api/topo/Edge.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2012-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.features.topology.api.topo;

import com.vaadin.v7.data.Item;

public interface Edge extends EdgeRef, Cloneable {

	Edge clone();

	/**
	 * Allow code to override the ID on cloned instances.
	 */
	void setId(String id);

	/**
	 * @deprecated Use namespace/id tuple
	 */
	String getKey();

	Item getItem();

	Connector getSource();

	Connector getTarget();

	@Override
	String getLabel();

	String getTooltipText();

	void setTooltipText(String tooltipText);

	String getStyleName();

	void setStyleName(String styleName);

}
